package com.bwie.auth.consumer;

import com.rabbitmq.client.Channel;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.io.IOException;

/**
 * @Author：杨鹏
 * @Package：com.bwie.auth.consumer
 * @Project：yp_yuekao812
 * @name：messageConsumer
 * @Date：2024/8/12 10:36
 */

@Log4j2
@Component
public class MessageConsumer {

    @Autowired
    private StringRedisTemplate redisTemplate;

    private static final String INDEX_SET = "INDEX_SET";

    @RabbitListener(queuesToDeclare = {@Queue("http_yp_lv")})
    public void messageConsumer(String userPhone, Message message, Channel channel){

        try {
            //	保证消息的可靠性（2分）
            String messageId = message.getMessageProperties().getMessageId();
            Long add = redisTemplate.opsForSet().add(INDEX_SET, messageId);
            if (add > 0){

                log.info("短信开始发送....,手机号为:{}",userPhone);
                log.info("短信内容为: 登录成功");
                channel.basicAck(message.getMessageProperties().getDeliveryTag(),false);
                log.info("短信发送完成....");
            }

        } catch (Exception e) {
            try {
                channel.basicReject(message.getMessageProperties().getDeliveryTag(),true);
            } catch (IOException ex) {
                log.info("短信发送报错.... , 原因为: {}",ex.getMessage());
            }
            throw new RuntimeException(e);
        }

    }

}
