package com.bwie.auth.controller;

import com.bwie.auth.service.AuthService;
import com.bwie.common.domain.User;
import com.bwie.common.result.Result;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * @Author：杨鹏
 * @Package：com.bwie.auth.controller
 * @Project：yp_yuekao812
 * @name：AuthController
 * @Date：2024/8/12 9:53
 */
@Log4j2
@RestController
@RequestMapping("auth")
public class AuthController {

    @Autowired
    private AuthService authService;

    @Autowired
    private HttpServletRequest request;

    /**
     * 登录
     */
    @PostMapping("login")
    public Result<User> login(@RequestBody User user){
        log.info("方法名称: 登录,URI :{}, 请求方式 :{},参数:{}",request.getRequestURI(),request.getMethod(),user);
        Result<User> login = authService.login(user);
        log.info("方法名称: 登录,URI :{}, 请求方式 :{},响应结果:{}",request.getRequestURI(),request.getMethod(),login);
        return login;
    }

    /**
     * 登录认证
     */
    @GetMapping("info")
    public Result info(){
        log.info("方法名称: 登录认证,URI :{}, 请求方式 :{}}",request.getRequestURI(),request.getMethod());
        Result info = authService.info();
        log.info("方法名称: 登录认证,URI :{}, 请求方式 :{},响应结果:{}",request.getRequestURI(),request.getMethod(), info);
        return info;
    }

    /**
     * 退出登录
     */
    @PostMapping("logout")
    public Result logout(){
        log.info("方法名称: 退出登录,URI :{}, 请求方式 :{}",request.getRequestURI(),request.getMethod());
        authService.logout();
        log.info("方法名称: 退出登录,URI :{}, 请求方式 :{}",request.getRequestURI(),request.getMethod());
        return Result.success();
    }

    /**
     * 注册
     */
    @PostMapping("addUser")
    public Result addUser(@RequestBody User user){
        log.info("方法名称: 注册,URI :{}, 请求方式 :{},参数:{}",request.getRequestURI(),request.getMethod(),user);
        Result addUser = authService.addUser(user);
        log.info("方法名称: 注册,URI :{}, 请求方式 :{},响应结果:{}",request.getRequestURI(),request.getMethod(),addUser);
        return addUser;
    }



}
