package com.bwie.es.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.domain.Product;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.common.utils.StringUtils;
import com.bwie.es.service.EsService;
import lombok.extern.log4j.Log4j2;
import org.elasticsearch.action.bulk.BulkRequest;
import org.elasticsearch.action.index.IndexRequest;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.action.update.UpdateRequest;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.common.xcontent.ToXContent;
import org.elasticsearch.common.xcontent.XContentType;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.index.query.QueryStringQueryBuilder;
import org.elasticsearch.index.reindex.BulkByScrollResponse;
import org.elasticsearch.index.reindex.DeleteByQueryRequest;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.SearchHits;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @Author：杨鹏
 * @Package：com.bwie.es.service.impl
 * @Project：yp_yuekao812
 * @name：EsServiceImpl
 * @Date：2024/8/12 13:34
 */
@Log4j2
@Service
public class EsServiceImpl implements EsService {


    private static final String INDEX_ES ="produce_yp";


    @Autowired
    private RestHighLevelClient restHighLevelClient;

    /**
     * es列表查询
     */
    @Override
    public Result<PageResult<Product>> listProduce(Product product) {
        ArrayList<Product> productList = new ArrayList<>();
        Long total = 0L;
        try {
            SearchRequest searchRequest = new SearchRequest(INDEX_ES);
            SearchSourceBuilder searchSourceBuilder = new SearchSourceBuilder();
            BoolQueryBuilder boolQueryBuilder = QueryBuilders.boolQuery();
            if (!StringUtils.isAllEmpty(product.getProductName())){
                boolQueryBuilder.must(QueryBuilders.matchQuery("productName",product.getProductName()));
            }
            searchSourceBuilder.query(boolQueryBuilder);
            searchRequest.source(searchSourceBuilder);
            SearchResponse search = restHighLevelClient.search(searchRequest, RequestOptions.DEFAULT);
            SearchHits hits = search.getHits();
            total = hits.getTotalHits().value;
            SearchHit[] hitsHits = hits.getHits();
            for (SearchHit hitsHit : hitsHits) {
                String sourceAsString = hitsHit.getSourceAsString();
                Product product1 = JSONObject.parseObject(sourceAsString, Product.class);
                product1.setProductId(Long.valueOf(hitsHit.getId()));
                productList.add(product1);
            }
        } catch (Exception e) {
            log.info("方法名称: es列表查询 ,报错原因 {}",e.getMessage());
        }
        return PageResult.toResult(total, productList);
    }

    /**
     * es列表添加
     */
    @Override
    public void addProduce(Product product) {
        try {
            IndexRequest indexRequest = new IndexRequest(INDEX_ES);
            indexRequest.id(product.getProductId()+"")
                    .source(JSONObject.toJSONString(product));
            restHighLevelClient.index(indexRequest,RequestOptions.DEFAULT);
        } catch (Exception e) {
            log.info("方法名称: es列表添加 ,报错原因 {}",e.getMessage());
        }
    }

    /**
     * 批量同步添加
     */
    @Override
    public void adds(List<Product> productList) {
         try {
             BulkRequest bulkRequest = new BulkRequest();

             productList.forEach(product -> {
                 bulkRequest.add(new IndexRequest(INDEX_ES)
                         .id(product.getProductId()+"")
                         .source(XContentType.JSON,JSONObject.toJSONString(product)));
             });
             restHighLevelClient.bulk(bulkRequest, RequestOptions.DEFAULT);
         } catch (Exception e) {
             log.info("方法名称: 批量同步添加 ,报错原因 {}",e.getMessage());
         }
    }

    /**
     * 删除
     */
    @Override
    public void del() {
        try {
            DeleteByQueryRequest deleteByQueryRequest = new DeleteByQueryRequest();
            deleteByQueryRequest.setQuery(new QueryStringQueryBuilder(INDEX_ES));
            restHighLevelClient.deleteByQuery(deleteByQueryRequest,RequestOptions.DEFAULT);
        } catch (Exception e) {

        }

    }

    /**
     * es列表修改
     */
    @Override
    public void updProduce(Product product) {

        try {
            UpdateRequest updateRequest = new UpdateRequest();
            updateRequest.id(product.getProductId()+"")
                    .doc(XContentType.JSON,JSONObject.toJSONString(product));
            restHighLevelClient.update(updateRequest,RequestOptions.DEFAULT);
        } catch (Exception e) {
            log.info("方法名称: es列表修改 ,报错原因 {}",e.getMessage());
        }

    }
}
