package com.bwie.product.controller;

import com.bwie.common.domain.Instant;
import com.bwie.common.domain.Product;
import com.bwie.common.domain.Shopping;
import com.bwie.common.domain.response.ProductResp;
import com.bwie.common.result.Result;
import com.bwie.product.service.ProductService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author：杨鹏
 * @Package：com.bwie.product.controller
 * @Project：yp_yuekao812
 * @name：ProductController
 * @Date：2024/8/12 11:14
 */
@Log4j2
@RestController
@RequestMapping("product")
public class ProductController {

    @Autowired
    private ProductService productService;

    /**
     * 查询数据
     */
    @GetMapping("listProduct")
    public Result<List<Product>> listProduct(){
        return Result.success(productService.listProduct());
    }

    /**
     * 查询秒杀规则列表
     */
    @PostMapping("listInstant")
    public Result listInstant(@RequestBody Instant instant){
        return productService.listInstant(instant);
    }

    /**
     * 添加秒杀规则列表
     */
    @PostMapping("addInstant")
    public Result addInstant(@RequestBody Instant instant){
        return productService.addInstant(instant);
    }

    /**
     * 查询购物车
     */
    @GetMapping("listShopping")
    public Result listShopping(){
        return productService.listShopping();
    }

    /**
     * 添加购物车
     */
    @PostMapping("addShopping")
    public Result addShopping(@RequestBody Shopping shopping){
        return productService.addShopping(shopping);
    }

    /**
     * 购物车结算
     */
    @PostMapping("payment")
    public Result payment(@RequestBody ProductResp resp){
        return productService.payment(resp);
    }

}
