package com.bwie.product.service.impl;

import cn.hutool.core.util.PageUtil;
import com.alibaba.fastjson.JSONObject;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Instant;
import com.bwie.common.domain.Product;
import com.bwie.common.domain.Shopping;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.ProductResp;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.product.mapper.ProductMapper;
import com.bwie.product.service.ProductService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Random;

/**
 * @Author：杨鹏
 * @Package：com.bwie.product.service.impl
 * @Project：yp_yuekao812
 * @name：ProductServiceImpl
 * @Date：2024/8/12 11:13
 */
@Service
public class ProductServiceImpl implements ProductService {

    @Autowired
    private ProductMapper productMapper;

    @Autowired
    private HttpServletRequest request;

    @Autowired
    private StringRedisTemplate redisTemplate;

    /**
     * 查询数据
     */
    @Override
    public List<Product> listProduct() {
        return productMapper.listProduct();
    }

    /**
     * 查询秒杀规则列表
     */
    @Override
    public Result listInstant(Instant instant) {
        PageHelper.startPage(instant.getPageNum(),instant.getPageSize());
        List<Instant> instantList = productMapper.listInstant(instant);
        PageInfo<Instant> instantPageInfo = new PageInfo<>(instantList);
        return Result.success(instantPageInfo);
    }

    /**
     * 添加秒杀规则列表
     */
    @Override
    public Result addInstant(Instant instant) {
        Integer i = productMapper.addInstant(instant);
        return i>0?Result.success():Result.error();
    }

    /**
     * 查询购物车
     */
    @Override
    public Result listShopping() {
        List<Shopping> shoppingList = productMapper.listShopping();
        return Result.success(shoppingList);
    }

    /**
     * 添加购物车
     */
    @Override
    public Result addShopping(Shopping shopping) {
        //	查询购物车中是否有该商品
        Shopping shopping1 = productMapper.listShoppingProdcutId(shopping.getProductId());
        if (shopping1 != null){
            // 如购物车当中有此商品则购物车商品数量+1（2分）
            Integer i = productMapper.updShopping(shopping);
            return i>0?Result.success():Result.error();
        }
        //如购物车无此商品则加入购物车，
        Integer i = productMapper.addShopping(shopping);
        return i>0?Result.success():Result.error();
    }

    /**
     * 购物车结算
     */
    @Transactional
    @Override
    public Result payment(ProductResp resp) {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String user = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        User user1 = JSONObject.parseObject(user, User.class);
        //	使用余额进行结算，如果余额不足则支付失败（2分）
        if (user1.getUserPrice() < resp.getProductPrice()){
            return Result.error("余额不足,支付失败");
        }
        //	订单支付，商品redis、数据库库存减一（2分）
        //	订单支付过程中，请使用redis分布式锁解决超卖的问题（2分）
        List<String> shoppingIds = resp.getShoppingIds();
        for (String shoppingId : shoppingIds) {
            // 查询购物车中的商品
            Shopping shopping = productMapper.listShoppingId(shoppingId);
            // 删除购物车中的商品
            productMapper.delShoppingId(shoppingId);
            // 修改商品的数量
            productMapper.updProduct(shopping);
        }
        // 扣除用户余额
        user1.setUserPrice(resp.getProductPrice());
        productMapper.updUser(user1);
        //	当商品发生更改的时候需要异步与ES进行同步 （2分）


        return Result.success("","支付成功");
    }


}
